"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.InterfaceProperty = void 0;
const access_modifier_1 = require("./access-modifier");
const property_1 = require("./property");
const codegen_1 = require("@azure-tools/codegen");
const doc_comments_1 = require("./doc-comments");
class InterfaceProperty extends property_1.Property {
    constructor(name, type, objectInitializer) {
        super(name, type);
        this.getAccess = access_modifier_1.Access.Public;
        this.setAccess = access_modifier_1.Access.Public;
        this.apply(objectInitializer);
    }
    get declaration() {
        const get = this.getAccess === access_modifier_1.Access.Public ? 'get;' : '';
        const set = this.setAccess === access_modifier_1.Access.Public ? 'set;' : '';
        return `${codegen_1.docComment(doc_comments_1.summary(this.description))}
${this.attributeDeclaration}${this.type.declaration} ${this.name} { ${get} ${set} }`;
    }
}
exports.InterfaceProperty = InterfaceProperty;
//# sourceMappingURL=interface-property.js.map