"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.ForEach = exports.For = exports.ForEachStatement = exports.ForStatement = void 0;
const codegen_1 = require("@azure-tools/codegen");
const expression_1 = require("../expression");
const statement_1 = require("./statement");
class ForStatement extends statement_1.Statements {
    constructor(initialization, condition, loop, statements, objectInitializer) {
        super(statements);
        this.initialization = initialization;
        this.condition = condition;
        this.loop = loop;
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
for( ${expression_1.valueOf(this.initialization)} ; ${expression_1.valueOf(this.condition)} ; ${expression_1.valueOf(this.loop)})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.ForStatement = ForStatement;
class ForEachStatement extends statement_1.Statements {
    constructor(variable, enumerable, statements, objectInitializer) {
        super(statements);
        this.variable = variable;
        this.enumerable = enumerable;
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
foreach( var ${this.variable} in ${expression_1.valueOf(this.enumerable)} )
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.ForEachStatement = ForEachStatement;
function For(initialization, condition, loop, statements, objectInitializer) {
    return new ForStatement(initialization, condition, loop, statements, objectInitializer);
}
exports.For = For;
function ForEach(variable, enumerable, statements, objectInitializer) {
    return new ForEachStatement(variable, enumerable, statements, objectInitializer);
}
exports.ForEach = ForEach;
//# sourceMappingURL=for.js.map