"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.While = exports.DoWhile = exports.Else = exports.If = exports.IsAssignableFrom = exports.Not = exports.ElseStatement = exports.ElseIf = exports.ElseIfStatement = exports.DoWhileStatement = exports.WhileStatement = exports.IfStatement = void 0;
const codegen_1 = require("@azure-tools/codegen");
const expression_1 = require("../expression");
const statement_1 = require("./statement");
class IfStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = conditional;
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
if (${expression_1.valueOf(this.conditional)})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.IfStatement = IfStatement;
class WhileStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = expression_1.toExpression(conditional);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
while (${this.conditional.value})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.WhileStatement = WhileStatement;
class DoWhileStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = expression_1.toExpression(conditional);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
do 
{
${codegen_1.indent(super.implementation)}
} while (${this.conditional.value})`.trim();
    }
}
exports.DoWhileStatement = DoWhileStatement;
class ElseIfStatement extends statement_1.Statements {
    constructor(conditional, statements, objectInitializer) {
        super(statements);
        this.conditional = expression_1.toExpression(conditional);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
else if (${this.conditional.value})
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.ElseIfStatement = ElseIfStatement;
function ElseIf(conditional, statements, objectInitializer) {
    return new ElseIfStatement(conditional, statements, objectInitializer);
}
exports.ElseIf = ElseIf;
class ElseStatement extends statement_1.Statements {
    constructor(statements, objectInitializer) {
        super(statements);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
else
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.ElseStatement = ElseStatement;
function Not(conditional) {
    return new expression_1.LiteralExpression(`!(${conditional.value})`);
}
exports.Not = Not;
function IsAssignableFrom(targetType, instanceType) {
    return expression_1.toExpression(`typeof(${targetType.declaration}).IsAssignableFrom(${expression_1.valueOf(instanceType)})`);
}
exports.IsAssignableFrom = IsAssignableFrom;
function If(conditional, statements, objectInitializer) {
    return new IfStatement(conditional, statements, objectInitializer);
}
exports.If = If;
function Else(statements, objectInitializer) {
    return new ElseStatement(statements, objectInitializer);
}
exports.Else = Else;
function DoWhile(conditional, statements, objectInitializer) {
    return new DoWhileStatement(conditional, statements, objectInitializer);
}
exports.DoWhile = DoWhile;
function While(conditional, statements, objectInitializer) {
    return new WhileStatement(conditional, statements, objectInitializer);
}
exports.While = While;
//# sourceMappingURL=if.js.map