"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockStatement = exports.Statements = exports.isStatement = exports.toStatement = void 0;
const codegen_1 = require("@azure-tools/codegen");
const literal_1 = require("./literal");
const linq_1 = require("@azure-tools/linq");
function toStatement(statement) {
    return typeof statement === 'string' ? new literal_1.LiteralStatement(statement) : statement;
}
exports.toStatement = toStatement;
function isStatement(object) {
    return object && object.implementation ? true : false;
}
exports.isStatement = isStatement;
class Statements extends codegen_1.Initializer {
    constructor(statements, objectIntializer) {
        super();
        this.statements = new Array();
        this.scope = new Array();
        this.scope.push(this);
        if (statements) {
            this.add(statements);
        }
        this.apply(objectIntializer);
    }
    push(innerScope) {
        this.add(innerScope);
        this.scope.push(innerScope);
        return this.scope.last;
    }
    pop() {
        if (this.scope.last === this) {
            throw new Error('Can not pop past base of statement collection.');
        }
        this.scope.pop();
        return this.scope.last;
    }
    get count() {
        return linq_1.length(this.statements);
    }
    insert(statements) {
        if (statements) {
            if (typeof (statements) === 'string') {
                this.statements.splice(0, 0, new literal_1.LiteralStatement(statements));
                return this;
            }
            if (statements instanceof Statements) {
                this.statements.splice(0, 0, statements);
                return this;
            }
            if (isStatement(statements)) {
                this.statements.splice(0, 0, statements);
                return this;
            }
            if (typeof (statements) === 'function') {
                return this.insert(statements());
            }
            for (const each of statements) {
                this.insert(each);
            }
        }
        return this;
    }
    add(statements) {
        if (statements) {
            if (this.scope.last !== this) {
                this.scope.last.add(statements);
                return this;
            }
            if (typeof (statements) === 'string') {
                this.statements.push(new literal_1.LiteralStatement(statements));
                return this;
            }
            if (statements instanceof Statements) {
                this.statements.push(statements);
                return this;
            }
            if (isStatement(statements)) {
                this.statements.push(statements);
                return this;
            }
            if (typeof (statements) === 'function') {
                return this.add(statements());
            }
            for (const each of statements) {
                this.add(each);
            }
        }
        return this;
    }
    get implementation() {
        return `${this.statements.joinWith(each => each.implementation, codegen_1.EOL)}`.trim();
    }
}
exports.Statements = Statements;
function* BlockStatement(statements) {
    yield '{';
    yield codegen_1.indent(new Statements(statements).implementation);
    yield '}';
}
exports.BlockStatement = BlockStatement;
//# sourceMappingURL=statement.js.map