"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports._Catch = exports.Try = exports._CatchStatement = exports.TryStatement = void 0;
const codegen_1 = require("@azure-tools/codegen");
const statement_1 = require("./statement");
class TryStatement extends statement_1.Statements {
    constructor(body, objectInitializer) {
        super(body);
        this.apply(objectInitializer);
    }
    get implementation() {
        return `
try
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports.TryStatement = TryStatement;
/* eslint-disable */ // is this supposed to be removed? 
class _CatchStatement extends statement_1.Statements {
    constructor(parameter, body, objectInitializer) {
        super(body);
        this.parameter = parameter;
        this.apply(objectInitializer);
    }
    get implementation() {
        const p = this.parameter ? ` (${this.parameter.declaration})` : '';
        return `
catch${p}
{
${codegen_1.indent(super.implementation)}
}`.trim();
    }
}
exports._CatchStatement = _CatchStatement;
function Try(body, objectInitializer) {
    return new TryStatement(body, objectInitializer);
}
exports.Try = Try;
function _Catch(parameter, body, objectInitializer) {
    return new _CatchStatement(parameter, body, objectInitializer);
}
exports._Catch = _Catch;
//# sourceMappingURL=try.js.map